# Support

There are many ways to get help with your issues.

- Open a GitHub issue in the respective GitHub repository.

- Chat with contributors on IRC in the `#standard` channel on Freenode.

- Get a support contract

  - The lead maintainer, Feross, offers an [open source support contract](https://awa.si/support/), for companies and teams who want dedicated support, advice, and direct assistance with Python, security, or open source issues.
